#
# spec file for package libcddb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor utils%{nil}
%define BUILD_UTILS 0
%if "%{flavor}" == "utils"
%define BUILD_UTILS 1
%define nsuffix -utils
%endif
# To break libcddb<->libcdio dependency loop, this package is built in two stages.
%define _name libcddb
Name:           libcddb%{?nsuffix}
Version:        1.3.2
Release:        29.3
Summary:        CDDB Access Library Utilities
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://libcddb.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/%{_name}/%{_name}/%{version}/%{_name}-%{version}.tar.bz2
Source2:        baselibs.conf
Patch0:         libcddb-no-examples.patch
# PATCH-FIX-UPSTREAM pointer-types.patch bsc#1221698 mcepl@suse.com
# Patch from https://src.fedoraproject.org/rpms/libcddb/raw/rawhide/f/pointer-types.patch
Patch1:         pointer-types.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if %{BUILD_UTILS}
BuildRequires:  libcddb-devel
BuildRequires:  libcdio-devel
%endif

%description
Libcddb is a library that implements the different protocols (CDDBP,
HTTP, and SMTP) to access data on a CDDB server (http://freedb.org). It
tries to be as cross-platform as possible.

%if ! %{BUILD_UTILS}
%package -n libcddb2
Summary:        CDDB Access Library
Group:          System/Libraries
#
Provides:       %{_name} = %{version}
#opensuse 10.3
Obsoletes:      %{_name} <= 1.3.0

%description -n libcddb2
Libcddb is a library that implements the different protocols (CDDBP,
HTTP, and SMTP) to access data on a CDDB server (http://freedb.org). It
tries to be as cross-platform as possible.

%package devel
Summary:        CDDB Access Library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libcddb2 = %{version}

%description devel
Libcddb is a library that implements the different protocols (CDDBP,
HTTP, and SMTP) to access data on a CDDB server (http://freedb.org). It
tries to be as cross-platform as possible.
%endif

%prep
%setup -q -n %{_name}-%{version}
%if !%{BUILD_UTILS}
%patch -p1 -P 0
%else
sed -i 's:\(\.\.\|\$(top_builddir)\)/[^/]*/lib\([^ ]*\)\.la:-l\2:g' */Makefile.am
%endif
%patch -p1 -P 1

%build
autoreconf -f -i
%configure\
	--disable-rpath\
	--disable-static
%if %{BUILD_UTILS}
cd examples
%endif
%make_build

%install
%if %{BUILD_UTILS}
cd examples
%endif
%make_install
rm -f %{buildroot}%{_libdir}/libcddb.la

%if %{BUILD_UTILS}
%files
%{_bindir}/*

%else

%ldconfig_scriptlets -n libcddb2

%files -n libcddb2
%{_libdir}/*.so.2*

%files devel
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS TODO
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/cddb
%endif

%changelog
* Fri Mar 22 2024 Matej Cepl <mcepl@cepl.eu>
- Add pointer-types.patch to fix compilation error with GCC 14
  (bsc#1221698).
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Transform into a proper _multibuild package: the spec is already
  prepared and uses a few variables to distinguish flavors.
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
- Trim old/redundant rpm constructs
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Feb 16 2012 coolo@suse.com
- move license outside a %%if to fix build of libcddb-utils
* Thu Jan 19 2012 coolo@suse.com
- fix pre_checkin.sh
* Thu Dec  1 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Thu Aug  6 2009 sbrabec@suse.cz
- Updated to version 1.3.2:
  * ported to more platforms
  * new functions in the API
  * minor fixes
- Build in two stages to break build loop without removing
  utilities.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Dec  4 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Nov 27 2008 ro@suse.de
- update baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Oct  9 2007 crrodriguez@suse.de
- fix build using library packaging policy
- remove static libraries and useless libtool archive
- permanently break build loop by removing the example code that caused it
* Tue Sep 11 2007 sbrabec@suse.cz
- Break build loop libcddb -> libcdio -> libcddb.
* Fri Oct 20 2006 sbrabec@suse.cz
- Updated to version 1.3.0:
  * Support for the 'album' command of the freedb2.org.
  * Functions to set or reset some flags.
* Fri Oct  6 2006 sbrabec@suse.cz
- Updated to version 1.2.2:
  * Correct character set is specified when submitting data.
* Fri Jun 30 2006 sbrabec@suse.cz
- Fixed cyclic dependencies in a correct way.
* Thu Jun 22 2006 sbrabec@suse.cz
- Simpler solution of cyclic dependencies.
* Tue Jan 31 2006 sbrabec@suse.cz
- Enabled parallel build.
- Fixed devel splitting.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 26 2005 sbrabec@suse.cz
- Build with libcdio-0.76.
* Fri Aug  5 2005 sbrabec@suse.cz
- Updated to version 1.2.1.
* Fri Jul 29 2005 sbrabec@suse.cz
- Updated to version 1.2.0.
* Mon May  9 2005 sbrabec@suse.cz
- Updated to version 1.0.2.
* Tue Apr 26 2005 sbrabec@suse.cz
- Updated to version 1.0.1.
* Tue Nov  9 2004 sbrabec@suse.cz
- New SuSE package, version 0.9.6.
